@@ -29,19 +29,15 @@
 
 #include "mainWindow/kpMainWindow.h"
 #include "kpMainWindowPrivate.h"
+#include "kpLogCategories.h"
 
-#include <qdatetime.h>
-#include <qpainter.h>
-#include <qtimer.h>
 #include <QScrollBar>
 
-#include <kapplication.h>
-#include "kpLogCategories.h"
-#include <klocale.h>
 #include <kselectaction.h>
 #include <kstandardaction.h>
 #include <ktoggleaction.h>
 #include <kactioncollection.h>
+#include <KLocalizedString>
 
 #include "kpDefs.h"
 #include "document/kpDocument.h"
